<template>

    <div 
        :class="[showtype=='home'?'map-con-home':'', 'map-con']" 
        ref = "mapView"
        :style="{height: pendingContentH + 'px'}">
      <div class="view-map">
        <span @click="normalMap()" :class="mapNum==1?'map-color':''">{{$t('map')}}</span>
        <span @click="mixMap()" :class="mapNum==2?'map-color':''">{{$t('satellite')}}</span>
      </div>
      <baidu-map
        id="box"
        :center="center" 
        :zoom="zoom"  
        class="bm-view"
        :mapType="currentMapType"
        @dblclick="getDbclickInfo"
        :double-click-zoom = "false"
        @zoomend="zoomEnd"
        >
        <div v-if="viewDataList.data && viewDataList.data.length>0">
          <div v-for="(item,index) in viewDataList.data" :key="index">
            <bm-marker :position="item.local?item.local:{lng:'',lat:''}" @click="infoWindowOpen(item.id, item)">
              <!-- <bm-info-window 
                :show="show" 
                @close="infoWindowClose" 
                @open="infoWindowOpen"
                style="width:280px;height:220px;"
              >

              </bm-info-window> -->
            </bm-marker>
          </div>
        </div>
        <!-- <bm-map-type :map-types="['BMAP_NORMAL_MAP', 'BMAP_HYBRID_MAP']" anchor="BMAP_ANCHOR_TOP_RIGHT"></bm-map-type> -->
        <bm-navigation anchor="BMAP_ANCHOR_BOTTOM_RIGHT"></bm-navigation>
        <bm-geolocation anchor="BMAP_ANCHOR_TOP_RIGHT" 
          :showAddressBar="true" 
          :autoLocation="true">
        </bm-geolocation>
        <bm-local-search 
          :keyword="location" 
          :auto-viewport="true" 
          style="display: none"
        >
        </bm-local-search>
        <bm-context-menu>
          <bm-context-menu-item :callback="setSign" :text="$t('maskPoint')"></bm-context-menu-item>
          <bm-context-menu-item :callback="cancelSign" :text="$t('cancelPoint')"></bm-context-menu-item>
          <bm-context-menu-item :callback="enlargeMap" :text="$t('enlarge')"></bm-context-menu-item>
          <bm-context-menu-item :callback="reduceMap" :text="$t('reduce')"></bm-context-menu-item>
        </bm-context-menu>
      </baidu-map>
      <comm-dialog
        v-if="dialogVisible"
        :visible.sync="dialogVisible"
        :lock-scroll="true"
        position="bottom"
      >
        <div class="local-detail">
          <div class="map-title">{{localDetail[0].value}}</div>
          <div class="content">{{localDetail[1].name}}：{{localDetail[1].value}}</div>
          <div class="coum">{{localDetail[2].name}}：{{localDetail[2].value}}</div>
          <div class="delBtn">
            <div class="btn" @click="Delete(id)">
              {{$t('del')}}
            </div>
          </div>
        </div>
      </comm-dialog>
    </div>
</template>

<script>
import { Toast } from 'mint-ui';
export default {
  inject:['reload'],
  name: "view-mapview",
  props: ["view", "showtype"],
  data: function() {
		return {
      center: {
        lng: 113.261503, 
        lat: 23.131377
      },
      zoom: 9,
      isActive:false,
      currentMapType:"BMAP_NORMAL_MAP",
      mapNum:1,
      currentLongitude:"",
      currentLatitude:"",
      keyword: '',
      location:'',
      show: false,
      markerPoint: {
        
      },
      markerAdress:'',
      adressTitle:'',
      adressContent:'',
      markerHidden:true,
      viewDataList:'',
      markerList:[],
      dialogVisible:false,
      localDetail:'',
      id:'',
      pendingContentH: "",
		}
  },
  mounted() {
    this.getData();
    this.$nextTick(function() {
      if(this.$refs.mapView) {
        this.pendingContentH =
          document.documentElement.clientHeight -
          this.$refs.mapView.getBoundingClientRect().top;
      }
    });
  },
  methods: {
    getData() {
      this.$api.getViewData(
        //普通试图接口
        this.$root.appid,
        this.view.id,
        {},

        {},
        {
          onSucess: response => {

            let viewData = response.data.data;
            //let map = new BMap.Map();
            let myGeo = new BMap.Geocoder();
            for(let i=0; i<viewData.data.length; i++) {
              for(let j=0; j<this.view.columns.length; j++) {
               
                let obj = {};
                if(j == 1) {
                  let addressData = viewData.data[i].items[this.view.columns[j].id];
                  let address = addressData.value; 
                  myGeo.getPoint(address ,(point) => {
                    obj.lng = point.lng;
                    obj.lat = point.lat;
                    viewData.data[i].local = obj;
                  }) 
                }
              }
            }
            this.viewDataList = viewData;
            console.log("viewData-->",this.viewDataList)
            // let arrLocal = [];
            // for(let y=0; y<arr.length; y++) {
            //   let obj = {};
            //   myGeo.getPoint(arr[y] ,(point) => {
            //     obj.lng = point.lng;
            //     obj.lat = point.lat;
            //     arrLocal.push(obj);
            //   })
            // }
            // this.markerList = arrLocal;
            // var searchTxt = "广州市天河区";
            // myGeo.getPoint(searchTxt,(point) => {
            //   console.log("point.lat--->",point.lat)  
            //   console.log("point.lng--->",point.lng)
            // })
          }
        }
      );
    },
    handler ({BMap, map}) {
      this.center.lng = 113.261503;
      this.center.lat = 23.131377;
      this.zoom = 9
      console.log(BMap);
      console.log(map);
    },
    zoomEnd(e){
      console.log(e)
      this.zoom = e.target.getZoom();
    },
    //右键放大
    enlargeMap(e){
      this.center = {
        lng: e.point.lng,
        lat: e.point.lat
      };
      this.zoom = this.zoom+2;
      if(this.zoom>=19){
        this.zoom = 19;
      }
      console.log(this.zoom);
    },
    //右键缩小
    reduceMap(e){
      this.center = {
        lng: e.point.lng,
        lat: e.point.lat
      };
      this.zoom = this.zoom-2;
      if(this.zoom<=0) {
        this.zoom = 1
      }
    },
    setSign(e){
      let mLng = e.point.lng,
          mLat = e.point.lat;
      this.setMark(mLng, mLat);
    },
    cancelSign({BMap, map}){
      //有问题，隐藏
      this.markerHidden = false;
      console.log(BMap);
      console.log(map);
    },
    infoWindowClose () {
      this.show = false
    },
    infoWindowOpen (id,item) {
      let arr = [];
      for(let j=0; j<this.view.columns.length; j++) {   
        let obj = {};
        let name = item.items[this.view.columns[j].id].name;
        let value = item.items[this.view.columns[j].id].value;
        obj.name = name,
        obj.value = value;
        arr.push(obj);
      }
      this.localDetail = arr;
      this.dialogVisible = true;
      this.show = true
      this.id = id;
    },
    getDbclickInfo (e) {
      let mLng = e.point.lng,
          mLat = e.point.lat;
      this.setMark(mLng, mLat);
    },
    normalMap(){
      if(this.mapNum == 2) {
        this.currentMapType = "BMAP_NORMAL_MAP"
        this.mapNum = 1;
      }
    },
    mixMap(){
      if(this.mapNum == 1) {
        this.currentMapType = "BMAP_HYBRID_MAP"
        this.mapNum = 2;
      }
    },
    searchLocation(){
      this.location = this.keyword;
    },
    searchBox(e) {
      this.isActive = !this.isActive;
      console.log(e);
    },
    Delete(id){
      let that = this;
      console.log('删除',id)
      let arr =[];
      arr.push(id);
      this.$api.batchRemoveDocuments(this.$root.appid, arr, {
        onSucess: () => {
          Toast({
            message: "删除成功",
            iconClass: 'fa fa-check fa-2x'
          });
          that.dialogVisible = false;
          setTimeout(()=>{
            that.reload();
          },100)
        }
      });
    }
  }
}
</script>

<style lang="scss">
  .map-con {
    margin-top:44px;
    height:100%;
    position:relative;
    .v-modal {
        position: fixed;
        left: 0;
        top: 0;
        width: 100%;
        height: 100%;
        opacity: 0;
        background: #fff !important;
    }
    .local-detail {
        width:100%;
        min-height:220px;
        position: absolute;
        bottom: -30px;
        left: 0;
        background: white;
        z-index: 6666;
        .map-title {
          width:100%;
          padding: 0 10px;
          box-sizing: border-box;
          height: 40px;
          line-height: 40px;
          font-size: 16px;
        }
        .content {
          width:100%;
          padding: 5px 10px;
 
          box-sizing: border-box;
        }
        .coum {
          width:100%;
          padding: 5px 10px;
          box-sizing: border-box;
        }
        .delBtn {
          width:100%;
          height: 50px;
          padding: 0px 10px;
          box-sizing: border-box;
          position: absolute;
          bottom:30px;
          left:0px;
          display: -webkit-flex;
          display: flex;
          align-items: center;
          border-top:1px solid #efeff4;
          .btn {
            width: 100%;
            height:30px;
            border:1px solid #4db3ff;
            font-size: 16px;
            color: #4db3ff;
            border-radius: 4px;
            line-height: 30px;
            text-align: center;
          }
        }
    }
    .bm-view{
      height: 100%;
      .BMap_stdMpZoom{
        top: -50px
      }
    }
  }

  .b-view {
    margin:0 auto;
    width: 95%;
    height: 90%;
  }
  .isHidden {
    display: none;
  }
  .btns{
    padding:2px 7px;
    font-size: 11px;
  }
  .view-map {
    width:75px;
    height:20px;
    position:absolute;
    left: 20px;
    top: 20px;
    z-index:5000;
    display:-webkit-flex;
    display: flex;
    flex-direction: row;
    background:white;
    border:1px solid #8ea8e0;
    border-radius: 4px;
    overflow: hidden;
    -webkit-box-shadow:2px 2px 4px #8ea8e0;  
    -moz-box-shadow:2px 2px 4px #8ea8e0;  
    box-shadow:2px 2px 4px #8ea8e0; 
    span {
      cursor:pointer;
      display:block;
      width:50%;
      height:20px;
      line-height: 20px;
      text-align: center;
      font-size:12px;
    }
  }
  .map-color{
    background:#8ea8e0;
    color:white;
    font-weight:bold;
  }
  .address-wrap {
    width:100%;
    &>div{
      width:100%;
      display:-webkit-flex;
      display: flex;
      flex-direction:row;
      &>div{
        height:40px;
        line-height:40px;
        vertical-align:middle;
        white-space:nowrap;
      }
      &:first-child {
        margin: 5px 0 10px 0;
        font-weight: bold;
      }
    }
    .info {
      margin-bottom:30px;
    }
    .common {
      margin-bottom: 15px;
    }
    .add-btn {
      display: -webkit-flex;
      display:flex;
      justify-content: center;
      &>span {
        margin-right:30px;
      }
    }
  }

  .map-con-home {
     margin-top: 0px;
  }
</style>